@@ -176,7 +176,7 @@ object LinkisJobBuilder {
 
   var authTokenValue: String = CommonVars[String](
     "wds.linkis.client.test.common.tokenValue",
-    "LINKIS_CLI_TEST"
+    Configuration.LINKIS_TOKEN.getValue
   ).getValue // This is the default authToken, we usually suggest set different ones for users.
 
   def setDefaultClientConfig(clientConfig: DWSClientConfig): Unit = this.clientConfig = clientConfig
