@@ -23,28 +23,29 @@ import org.apache.linkis.common.exception.LinkisRetryException;
 import org.apache.linkis.common.utils.ByteTimeUtils;
 import org.apache.linkis.common.utils.JsonUtils;
 import org.apache.linkis.governance.common.conf.GovernanceCommonConf;
+import org.apache.linkis.governance.common.constant.ec.ECConstants;
+import org.apache.linkis.governance.common.utils.JobUtils;
+import org.apache.linkis.governance.common.utils.LoggerUtils;
 import org.apache.linkis.manager.am.conf.AMConfiguration;
 import org.apache.linkis.manager.am.exception.AMErrorCode;
 import org.apache.linkis.manager.am.exception.AMErrorException;
 import org.apache.linkis.manager.am.manager.EngineNodeManager;
 import org.apache.linkis.manager.am.service.ECResourceInfoService;
-import org.apache.linkis.manager.am.service.engine.EngineCreateService;
-import org.apache.linkis.manager.am.service.engine.EngineInfoService;
-import org.apache.linkis.manager.am.service.engine.EngineOperateService;
-import org.apache.linkis.manager.am.service.engine.EngineStopService;
+import org.apache.linkis.manager.am.service.engine.*;
 import org.apache.linkis.manager.am.util.ECResourceInfoUtils;
 import org.apache.linkis.manager.am.utils.AMUtils;
 import org.apache.linkis.manager.am.vo.AMEngineNodeVo;
+import org.apache.linkis.manager.common.constant.AMConstant;
+import org.apache.linkis.manager.common.entity.enumeration.NodeHealthy;
 import org.apache.linkis.manager.common.entity.enumeration.NodeStatus;
 import org.apache.linkis.manager.common.entity.node.AMEMNode;
+import org.apache.linkis.manager.common.entity.node.EMNode;
 import org.apache.linkis.manager.common.entity.node.EngineNode;
 import org.apache.linkis.manager.common.entity.persistence.ECResourceInfoRecord;
-import org.apache.linkis.manager.common.protocol.engine.EngineCreateRequest;
-import org.apache.linkis.manager.common.protocol.engine.EngineOperateRequest;
-import org.apache.linkis.manager.common.protocol.engine.EngineOperateResponse;
-import org.apache.linkis.manager.common.protocol.engine.EngineStopRequest;
+import org.apache.linkis.manager.common.protocol.engine.*;
 import org.apache.linkis.manager.label.builder.factory.LabelBuilderFactory;
 import org.apache.linkis.manager.label.builder.factory.LabelBuilderFactoryContext;
+import org.apache.linkis.manager.label.constant.LabelKeyConstant;
 import org.apache.linkis.manager.label.entity.Label;
 import org.apache.linkis.manager.label.entity.UserModifiable;
 import org.apache.linkis.manager.label.exception.LabelErrorException;
@@ -52,6 +53,7 @@ import org.apache.linkis.manager.label.service.NodeLabelService;
 import org.apache.linkis.rpc.Sender;
 import org.apache.linkis.server.Message;
 import org.apache.linkis.server.utils.ModuleUserUtils;
+import org.apache.linkis.storage.utils.StorageUtils;
 
 import org.apache.commons.collections.CollectionUtils;
 import org.apache.commons.lang3.StringUtils;
@@ -65,11 +67,10 @@ import javax.servlet.http.HttpServletRequest;
 import java.io.IOException;
 import java.text.MessageFormat;
 import java.util.*;
+import java.util.concurrent.Callable;
 import java.util.stream.Collectors;
 import java.util.stream.Stream;
 
-import scala.annotation.meta.param;
-
 import com.fasterxml.jackson.core.JsonProcessingException;
 import com.fasterxml.jackson.core.type.TypeReference;
 import com.fasterxml.jackson.databind.JsonNode;
@@ -91,6 +92,7 @@ public class EngineRestfulApi {
 
   @Autowired private EngineInfoService engineInfoService;
 
+  @Autowired private EngineAskEngineService engineAskService;
   @Autowired private EngineCreateService engineCreateService;
 
   @Autowired private EngineNodeManager engineNodeManager;
@@ -103,6 +105,8 @@ public class EngineRestfulApi {
 
   @Autowired private ECResourceInfoService ecResourceInfoService;
 
+  @Autowired private EngineReuseService engineReuseService;
+
   private final ObjectMapper objectMapper = new ObjectMapper();
 
   private LabelBuilderFactory stdLabelBuilderFactory =
@@ -110,6 +114,183 @@ public class EngineRestfulApi {
 
   private static final Logger logger = LoggerFactory.getLogger(EngineRestfulApi.class);
 
+  @ApiOperation(value = "askEngineConn", response = Message.class)
+  @ApiOperationSupport(ignoreParameters = {"jsonNode"})
+  @RequestMapping(path = "/askEngineConn", method = RequestMethod.POST)
+  public Message askEngineConn(
+      HttpServletRequest req, @RequestBody EngineAskRequest engineAskRequest)
+      throws IOException, InterruptedException {
+    String userName = ModuleUserUtils.getOperationUser(req, "askEngineConn");
+    engineAskRequest.setUser(userName);
+    long timeout = engineAskRequest.getTimeOut();
+    if (timeout <= 0) {
+      timeout = AMConfiguration.ENGINE_CONN_START_REST_MAX_WAIT_TIME.getValue().toLong();
+      engineAskRequest.setTimeOut(timeout);
+    }
+    Map<String, Object> retEngineNode = new HashMap<>();
+    logger.info(
+        "User {} try to ask an engineConn with maxStartTime {}. EngineAskRequest is {}.",
+        userName,
+        ByteTimeUtils.msDurationToString(timeout),
+        engineAskRequest);
+    Sender sender = Sender.getSender(Sender.getThisServiceInstance());
+    EngineNode engineNode = null;
+
+    // try to reuse ec first
+    String taskId = JobUtils.getJobIdFromStringMap(engineAskRequest.getProperties());
+    LoggerUtils.setJobIdMDC(taskId);
+    logger.info("received task : {}, engineAskRequest : {}", taskId, engineAskRequest);
+    if (!engineAskRequest.getLabels().containsKey(LabelKeyConstant.EXECUTE_ONCE_KEY)) {
+      EngineReuseRequest engineReuseRequest = new EngineReuseRequest();
+      engineReuseRequest.setLabels(engineAskRequest.getLabels());
+      engineReuseRequest.setTimeOut(engineAskRequest.getTimeOut());
+      engineReuseRequest.setUser(engineAskRequest.getUser());
+      engineReuseRequest.setProperties(engineAskRequest.getProperties());
+      boolean end = false;
+      EngineNode reuseNode = null;
+      int count = 0;
+      int MAX_RETRY = 2;
+      while (!end) {
+        try {
+          reuseNode = engineReuseService.reuseEngine(engineReuseRequest, sender);
+          end = true;
+        } catch (LinkisRetryException e) {
+          logger.error(
+              "task: {}, user: {} reuse engine failed", taskId, engineReuseRequest.getUser(), e);
+          Thread.sleep(1000);
+          end = false;
+          count += 1;
+          if (count > MAX_RETRY) {
+            end = true;
+          }
+        } catch (Exception e1) {
+          logger.info(
+              "task: {} user: {} reuse engine failed", taskId, engineReuseRequest.getUser(), e1);
+          end = true;
+        }
+      }
+      if (null != reuseNode) {
+        logger.info(
+            "Finished to ask engine for task: {}, user: {} by reuse node {}",
+            taskId,
+            engineReuseRequest.getUser(),
+            reuseNode);
+        LoggerUtils.removeJobIdMDC();
+        engineNode = reuseNode;
+      }
+    }
+
+    if (null != engineNode) {
+      fillResultEngineNode(retEngineNode, engineNode);
+      return Message.ok("reuse engineConn ended.").data("engine", retEngineNode);
+    }
+
+    String engineAskAsyncId = EngineAskEngineService$.MODULE$.getAsyncId();
+    Callable<Object> createECTask =
+        new Callable() {
+          @Override
+          public Object call() {
+            LoggerUtils.setJobIdMDC(taskId);
+            logger.info(
+                "Task: {}, start to async({}) createEngine: {}",
+                taskId,
+                engineAskAsyncId,
+                engineAskRequest.getCreateService());
+            // remove engineInstance label if exists
+            engineAskRequest.getLabels().remove("engineInstance");
+            EngineCreateRequest engineCreateRequest = new EngineCreateRequest();
+            engineCreateRequest.setLabels(engineAskRequest.getLabels());
+            engineCreateRequest.setTimeout(engineAskRequest.getTimeOut());
+            engineCreateRequest.setUser(engineAskRequest.getUser());
+            engineCreateRequest.setProperties(engineAskRequest.getProperties());
+            engineCreateRequest.setCreateService(engineAskRequest.getCreateService());
+            try {
+              EngineNode createNode = engineCreateService.createEngine(engineCreateRequest, sender);
+              long timeout = 0L;
+              if (engineCreateRequest.getTimeout() <= 0) {
+                timeout = AMConfiguration.ENGINE_START_MAX_TIME.getValue().toLong();
+              } else {
+                timeout = engineCreateRequest.getTimeout();
+              }
+              // useEngine need to add timeout
+              EngineNode createEngineNode = engineNodeManager.useEngine(createNode, timeout);
+              if (null == createEngineNode) {
+                throw new LinkisRetryException(
+                    AMConstant.EM_ERROR_CODE,
+                    "create engine${createNode.getServiceInstance} success, but to use engine failed");
+              }
+              logger.info(
+                  "Task: $taskId finished to ask engine for user ${engineAskRequest.getUser} by create node $createEngineNode");
+              return createEngineNode;
+            } catch (Exception e) {
+              logger.error(
+                  "Task: {} failed to ask engine for user {} by create node", taskId, userName, e);
+              return new LinkisRetryException(AMConstant.EM_ERROR_CODE, e.getMessage());
+            } finally {
+              LoggerUtils.removeJobIdMDC();
+            }
+          }
+        };
+
+    try {
+      Object rs = createECTask.call();
+      if (rs instanceof LinkisRetryException) {
+        throw (LinkisRetryException) rs;
+      } else {
+        engineNode = (EngineNode) rs;
+      }
+    } catch (LinkisRetryException retryException) {
+      logger.error(
+          "User {} create engineConn failed get retry  exception. can be Retry",
+          userName,
+          retryException);
+      return Message.error(
+              String.format(
+                  "Create engineConn failed, caused by %s.",
+                  ExceptionUtils.getRootCauseMessage(retryException)))
+          .data("canRetry", true);
+    } catch (Exception e) {
+      LoggerUtils.removeJobIdMDC();
+      logger.error("User {} create engineConn failed get retry  exception", userName, e);
+      return Message.error(
+          String.format(
+              "Create engineConn failed, caused by %s.", ExceptionUtils.getRootCauseMessage(e)));
+    }
+
+    LoggerUtils.removeJobIdMDC();
+    fillResultEngineNode(retEngineNode, engineNode);
+    logger.info(
+        "Finished to create a engineConn for user {}. NodeInfo is {}.", userName, engineNode);
+    // to transform to a map
+    return Message.ok("create engineConn ended.").data("engine", retEngineNode);
+  }
+
+  private void fillNullNode(
+      Map<String, Object> retEngineNode, EngineAskAsyncResponse askAsyncResponse) {
+    retEngineNode.put(AMConstant.EC_ASYNC_START_RESULT_KEY, AMConstant.EC_ASYNC_START_RESULT_FAIL);
+    retEngineNode.put(
+        AMConstant.EC_ASYNC_START_FAIL_MSG_KEY,
+        "Got null response for asyId : " + askAsyncResponse.id());
+    retEngineNode.put(ECConstants.MANAGER_SERVICE_INSTANCE_KEY(), Sender.getThisServiceInstance());
+  }
+
+  private void fillResultEngineNode(Map<String, Object> retEngineNode, EngineNode engineNode) {
+    retEngineNode.put(
+        AMConstant.EC_ASYNC_START_RESULT_KEY, AMConstant.EC_ASYNC_START_RESULT_SUCCESS);
+    retEngineNode.put("serviceInstance", engineNode.getServiceInstance());
+    if (null == engineNode.getNodeStatus()) {
+      engineNode.setNodeStatus(NodeStatus.Starting);
+    }
+    retEngineNode.put(ECConstants.NODE_STATUS_KEY(), engineNode.getNodeStatus().toString());
+    retEngineNode.put(ECConstants.EC_TICKET_ID_KEY(), engineNode.getTicketId());
+    EMNode emNode = engineNode.getEMNode();
+    if (null != emNode) {
+      retEngineNode.put(
+          ECConstants.ECM_SERVICE_INSTANCE_KEY(), engineNode.getEMNode().getServiceInstance());
+    }
+    retEngineNode.put(ECConstants.MANAGER_SERVICE_INSTANCE_KEY(), Sender.getThisServiceInstance());
+  }
+
   @ApiOperation(value = "createEngineConn", response = Message.class)
   @ApiOperationSupport(ignoreParameters = {"jsonNode"})
   @RequestMapping(path = "/createEngineConn", method = RequestMethod.POST)
@@ -120,7 +301,7 @@ public class EngineRestfulApi {
     engineCreateRequest.setUser(userName);
     long timeout = engineCreateRequest.getTimeout();
     if (timeout <= 0) {
-      timeout = AMConfiguration.ENGINE_CONN_START_REST_MAX_WAIT_TIME().getValue().toLong();
+      timeout = AMConfiguration.ENGINE_CONN_START_REST_MAX_WAIT_TIME.getValue().toLong();
       engineCreateRequest.setTimeout(timeout);
     }
     logger.info(
@@ -149,13 +330,7 @@ public class EngineRestfulApi {
         "Finished to create a engineConn for user {}. NodeInfo is {}.", userName, engineNode);
     // to transform to a map
     Map<String, Object> retEngineNode = new HashMap<>();
-    retEngineNode.put("serviceInstance", engineNode.getServiceInstance());
-    if (null == engineNode.getNodeStatus()) {
-      engineNode.setNodeStatus(NodeStatus.Starting);
-    }
-    retEngineNode.put("nodeStatus", engineNode.getNodeStatus().toString());
-    retEngineNode.put("ticketId", engineNode.getTicketId());
-    retEngineNode.put("ecmServiceInstance", engineNode.getEMNode().getServiceInstance());
+    fillResultEngineNode(retEngineNode, engineNode);
     return Message.ok("create engineConn succeed.").data("engine", retEngineNode);
   }
 
@@ -173,6 +348,7 @@ public class EngineRestfulApi {
     } catch (Exception e) {
       logger.info("Instances {} does not exist", serviceInstance.getInstance());
     }
+    String ecMetrics = null;
     if (null == engineNode) {
       ECResourceInfoRecord ecInfo = null;
       if (null != ticketIdNode) {
@@ -189,12 +365,19 @@ public class EngineRestfulApi {
       if (null == ecInfo) {
         return Message.error("Instance does not exist " + serviceInstance);
       }
+      if (null == ecMetrics) {
+        ecMetrics = ecInfo.getMetrics();
+      }
       engineNode = ECResourceInfoUtils.convertECInfoTOECNode(ecInfo);
+    } else {
+      ecMetrics = engineNode.getEcMetrics();
     }
     if (!userName.equals(engineNode.getOwner()) && Configuration.isNotAdmin(userName)) {
       return Message.error("You have no permission to access EngineConn " + serviceInstance);
     }
-    return Message.ok().data("engine", engineNode);
+    Message result = Message.ok().data("engine", engineNode);
+    result.data(AMConstant.EC_METRICS_KEY, ecMetrics);
+    return result;
   }
 
   @ApiOperation(value = "kill egineconn", notes = "kill engineconn", response = Message.class)
@@ -271,6 +454,7 @@ public class EngineRestfulApi {
     for (Map<String, String> engineParam : param) {
       String moduleName = engineParam.get("applicationName");
       String engineInstance = engineParam.get("engineInstance");
+      logger.info("try to kill engine with engineInstance:{}", engineInstance);
       EngineStopRequest stopEngineRequest =
           new EngineStopRequest(ServiceInstance.apply(moduleName, engineInstance), userName);
       engineStopService.stopEngine(stopEngineRequest, sender);
@@ -423,7 +607,8 @@ public class EngineRestfulApi {
     @ApiImplicitParam(name = "instance", dataType = "String", example = "bdp110:12295"),
     @ApiImplicitParam(name = "labels", dataType = "List", required = false, value = "labels"),
     @ApiImplicitParam(name = "labelKey", dataType = "String", example = "engineInstance"),
-    @ApiImplicitParam(name = "stringValue", dataType = "String", example = "linkis-cg:12295")
+    @ApiImplicitParam(name = "stringValue", dataType = "String", example = "linkis-cg:12295"),
+    @ApiImplicitParam(name = "nodeHealthy", dataType = "String", example = "UnHealthy")
   })
   @ApiOperationSupport(ignoreParameters = {"jsonNode"})
   @RequestMapping(path = "/modifyEngineInfo", method = RequestMethod.PUT)
@@ -435,6 +620,7 @@ public class EngineRestfulApi {
           210003, "Only admin can modify engineConn information(只有管理员才能修改引擎信息).");
     }
     ServiceInstance serviceInstance = getServiceInstance(jsonNode);
+
     JsonNode labels = jsonNode.get("labels");
     Set<String> labelKeySet = new HashSet<>();
     if (labels != null) {
@@ -458,9 +644,53 @@ public class EngineRestfulApi {
       nodeLabelService.updateLabelsToNode(serviceInstance, newLabelList);
       logger.info("success to update label of instance: " + serviceInstance.getInstance());
     }
+
+    // 修改引擎健康状态，只支持 Healthy和 UnHealthy
+    String healthyKey = "Healthy";
+    String unHealthyKey = "UnHealthy";
+    JsonNode nodeHealthy = jsonNode.get("nodeHealthy");
+    if (nodeHealthy != null && healthyKey.equals(nodeHealthy.asText())) {
+      engineInfoService.updateEngineHealthyStatus(serviceInstance, NodeHealthy.Healthy);
+    } else if (nodeHealthy != null && unHealthyKey.equals(nodeHealthy.asText())) {
+      engineInfoService.updateEngineHealthyStatus(serviceInstance, NodeHealthy.UnHealthy);
+    }
     return Message.ok("success to update engine information(更新引擎信息成功)");
   }
 
+  @ApiOperation(
+      value = "batchSetEngineToUnHealthy",
+      notes = "batch set engine to unHealthy",
+      response = Message.class)
+  @ApiImplicitParams({
+    @ApiImplicitParam(
+        name = "instances",
+        dataType = "String",
+        example =
+            "[{\"instance\":\"bdplinkis1001:38701\",\"engineType\":\"spark\",\"applicationName\":\"linkis-cg-engineconn\"}]")
+  })
+  @ApiOperationSupport(ignoreParameters = {"jsonNode"})
+  @RequestMapping(path = "/batchSetEngineToUnHealthy", method = RequestMethod.POST)
+  public Message batchSetEngineToUnHealthy(HttpServletRequest req, @RequestBody JsonNode jsonNode)
+      throws AMErrorException {
+    String username = ModuleUserUtils.getOperationUser(req, "batchSetEngineToUnHealthy");
+    if (Configuration.isNotAdmin(username)) {
+      throw new AMErrorException(
+          210003, "Only admin can modify engineConn healthy info(只有管理员才能修改引擎健康信息).");
+    }
+
+    JsonNode instances = jsonNode.get("instances");
+    if (instances != null) {
+      Iterator<JsonNode> iterator = instances.iterator();
+      while (iterator.hasNext()) {
+        JsonNode instanceNode = iterator.next();
+        ServiceInstance serviceInstance = getServiceInstance(instanceNode);
+        engineInfoService.updateEngineHealthyStatus(serviceInstance, NodeHealthy.UnHealthy);
+      }
+    }
+    logger.info("success to batch update engine status to UnHealthy.");
+    return Message.ok("success to update engine information(批量更新引擎健康信息成功)");
+  }
+
   @ApiOperation(
       value = "listAllNodeHealthyStatus",
       notes = "get all node healthy staus list",
@@ -484,6 +714,11 @@ public class EngineRestfulApi {
     ServiceInstance serviceInstance = getServiceInstance(jsonNode);
     logger.info("User {} try to execute Engine Operation {}.", userName, serviceInstance);
     EngineNode engineNode = engineNodeManager.getEngineNode(serviceInstance);
+    if (null == engineNode) {
+      return Message.ok()
+          .data("isError", true)
+          .data("errorMsg", "Ec : " + serviceInstance.toString() + " not found.");
+    }
     if (!userName.equals(engineNode.getOwner()) && Configuration.isNotAdmin(userName)) {
       return Message.error("You have no permission to execute Engine Operation " + serviceInstance);
     }
@@ -500,6 +735,45 @@ public class EngineRestfulApi {
         .data("isError", engineOperateResponse.isError());
   }
 
+  @ApiOperation(
+      value = "kill egineconns of a ecm",
+      notes = "Kill engine after updating configuration",
+      response = Message.class)
+  @ApiImplicitParams({
+    @ApiImplicitParam(name = "creator", dataType = "String", required = true, example = "IDE"),
+    @ApiImplicitParam(
+        name = "engineType",
+        dataType = "String",
+        required = true,
+        example = "hive-2.3.3"),
+  })
+  @ApiOperationSupport(ignoreParameters = {"param"})
+  @RequestMapping(path = "/rm/killEngineByUpdateConfig", method = RequestMethod.POST)
+  public Message killEngineByUpdateConfig(HttpServletRequest req, @RequestBody JsonNode jsonNode)
+      throws AMErrorException {
+    String userName = ModuleUserUtils.getOperationUser(req);
+    String jvmUser = StorageUtils.getJvmUser();
+    if (jvmUser.equals(userName)) {
+      return Message.error(
+          jvmUser + " users do not support this feature (" + jvmUser + " 用户不支持此功能)");
+    }
+    JsonNode creator = jsonNode.get("creator");
+    if (null == creator || StringUtils.isBlank(creator.textValue())) {
+      return Message.error("instance is null in the parameters of the request(请求参数中【creator】为空)");
+    }
+    String creatorStr = Configuration.getGlobalCreator(creator.textValue());
+    String engineType = "";
+    if (null != jsonNode.get("engineType")) {
+      engineType = jsonNode.get("engineType").textValue();
+    }
+    if (StringUtils.isNotBlank(engineType)
+        && AMConfiguration.isUnAllowKilledEngineType(engineType)) {
+      return Message.error("multi user engine does not support this feature(多用户引擎不支持此功能)");
+    }
+    engineStopService.stopUnlockECByUserCreatorAndECType(userName, creatorStr, engineType);
+    return Message.ok("Kill engineConn succeed");
+  }
+
   static ServiceInstance getServiceInstance(JsonNode jsonNode) throws AMErrorException {
     String applicationName = jsonNode.get("applicationName").asText();
     String instance = jsonNode.get("instance").asText();
