@@ -17,10 +17,11 @@
 
 package org.apache.linkis.manager.label.exception;
 
-import org.apache.linkis.common.exception.ErrorException;
+import org.apache.linkis.common.exception.ExceptionLevel;
+import org.apache.linkis.common.exception.LinkisRuntimeException;
 
 /** Define Exception */
-public class LabelErrorException extends ErrorException {
+public class LabelErrorException extends LinkisRuntimeException {
   public LabelErrorException(int errCode, String desc) {
     super(errCode, desc);
   }
@@ -29,4 +30,9 @@ public class LabelErrorException extends ErrorException {
     super(errCode, desc);
     this.initCause(t);
   }
+
+  @Override
+  public ExceptionLevel getLevel() {
+    return ExceptionLevel.ERROR;
+  }
 }
