@@ -43,4 +43,9 @@ public class EngineInfoClearRequest implements EngineRequest {
   public String getUser() {
     return user;
   }
+
+  @Override
+  public String toString() {
+    return "EngineInfoClearRequest{" + "engineNode=" + engineNode + ", user='" + user + '\'' + '}';
+  }
 }
