@@ -15,4 +15,5 @@
  * limitations under the License.
 */
 
-INSERT INTO linkis_ps_error_code (error_code,error_desc,error_regex,error_type) VALUES ('43015','当前节点需要的CS表解析失败，请检查当前CSID对应的CS表是否存在','Cannot parse cs table for node',0);
\ No newline at end of file
+select @data_source_type_id := id from `linkis_ps_dm_datasource_type` where `name` = 'doris';
+UPDATE linkis_ps_dm_datasource_type_key SET `require` = 0 WHERE `key` ="password" and `data_source_type_id` = @data_source_type_id;
