@@ -19,7 +19,7 @@ module Shell
   module Commands
     class ListSecurityCapabilities < Command
       def help
-        <<-EOF
+        return <<-EOF
 List supported security capabilities
 
 Example:
@@ -27,18 +27,20 @@ Example:
 EOF
       end
 
-      def command
-        list = admin.get_security_capabilities
-        list.each do |s|
-          puts s.getName
+      def command()
+        begin
+          list = admin.get_security_capabilities
+          list.each do |s|
+            puts s.getName
+          end
+          return list.map { |s| s.getName() }
+        rescue Exception => e
+          if e.to_s.include? "UnsupportedOperationException"
+            puts "ERROR: Master does not support getSecurityCapabilities"
+            return []
+          end
+          raise e
         end
-        return list.map(&:getName)
-      rescue Exception => e
-        if e.to_s.include? 'UnsupportedOperationException'
-          puts 'ERROR: Master does not support getSecurityCapabilities'
-          return []
-        end
-        raise e
       end
     end
   end
