@@ -23,7 +23,7 @@ module Shell
   module Commands
     class ShowFilters < Command
       def help
-        <<-EOF
+        return <<-EOF
 Show all the filters in hbase. Example:
   hbase> show_filters
 
@@ -35,7 +35,8 @@ Show all the filters in hbase. Example:
 EOF
       end
 
-      def command
+      def command( )
+        now = Time.now
         parseFilter = ParseFilter.new
         supportedFilters = parseFilter.getSupportedFilters
 
