@@ -20,9 +20,9 @@
 
 module Shell
   module Commands
-    class ShowPeerTableCFs < Command
+    class ShowPeerTableCFs< Command
       def help
-        <<-EOF
+          return <<-EOF
   Show replicable table-cf config for the specified peer.
 
     hbase> show_peer_tableCFs '2'
@@ -30,13 +30,7 @@ module Shell
       end
 
       def command(id)
-        peer_table_cfs = replication_admin.show_peer_tableCFs(id)
-        puts peer_table_cfs
-        peer_table_cfs
-      end
-
-      def command_name
-        'show_peer_tableCFs'
+        puts replication_admin.show_peer_tableCFs(id)
       end
     end
   end
