@@ -20,16 +20,18 @@ module Shell
   module Commands
     class Snapshot < Command
       def help
-        <<-EOF
+        return <<-EOF
 Take a snapshot of specified table. Examples:
 
   hbase> snapshot 'sourceTable', 'snapshotName'
-  hbase> snapshot 'namespace:sourceTable', 'snapshotName', {SKIP_FLUSH => true, MAX_FILESIZE => 21474836480}
+  hbase> snapshot 'namespace:sourceTable', 'snapshotName', {SKIP_FLUSH => true}
 EOF
       end
 
       def command(table, snapshot_name, *args)
-        admin.snapshot(table, snapshot_name, *args)
+        format_simple_command do
+          admin.snapshot(table, snapshot_name, *args)
+        end
       end
     end
   end
