@@ -20,7 +20,7 @@ module Shell
   module Commands
     class CleanerChoreEnabled < Command
       def help
-        return <<-EOF
+        <<-EOF
 Query for the Cleaner chore state (enabled/disabled?).
 Examples:
 
@@ -28,12 +28,8 @@ Examples:
 EOF
       end
 
-      def command()
-        format_simple_command do
-          formatter.row([
-            admin.cleaner_chore_enabled()? "true" : "false"
-          ])
-        end
+      def command
+        formatter.row([admin.cleaner_chore_enabled ? 'true' : 'false'])
       end
     end
   end
