@@ -20,10 +20,10 @@ module Shell
   module Commands
     class TableHelp < Command
       def help
-        return Hbase::Table.help
+        Hbase::Table.help
       end
 
-      #just print the help
+      # just print the help
       def command
         # call the shell to get the nice formatting there
         @shell.help_command 'table_help'
