@@ -19,12 +19,15 @@ package org.apache.linkis.engineplugin.trino.executor
 
 import org.apache.linkis.common.log.LogUtils
 import org.apache.linkis.common.utils.{OverloadUtils, Utils}
+import org.apache.linkis.engineconn.acessible.executor.listener.event.TaskLogUpdateEvent
 import org.apache.linkis.engineconn.common.conf.{EngineConnConf, EngineConnConstant}
+import org.apache.linkis.engineconn.computation.executor.conf.ComputationExecutorConf
 import org.apache.linkis.engineconn.computation.executor.execute.{
   ConcurrentComputationExecutor,
   EngineExecutionContext
 }
 import org.apache.linkis.engineconn.core.EngineConnObject
+import org.apache.linkis.engineconn.executor.listener.ExecutorListenerBusContext
 import org.apache.linkis.engineplugin.trino.conf.TrinoConfiguration._
 import org.apache.linkis.engineplugin.trino.conf.TrinoEngineConfig
 import org.apache.linkis.engineplugin.trino.exception.{
@@ -39,12 +42,12 @@ import org.apache.linkis.engineplugin.trino.password.{
 import org.apache.linkis.engineplugin.trino.socket.SocketChannelSocketFactory
 import org.apache.linkis.engineplugin.trino.utils.{TrinoCode, TrinoSQLHook}
 import org.apache.linkis.governance.common.paser.SQLCodeParser
+import org.apache.linkis.governance.common.utils.JobUtils
 import org.apache.linkis.manager.common.entity.resource.{
   CommonNodeResource,
   LoadResource,
   NodeResource
 }
-import org.apache.linkis.manager.engineplugin.common.conf.EngineConnPluginConf
 import org.apache.linkis.manager.engineplugin.common.util.NodeResourceUtils
 import org.apache.linkis.manager.label.entity.Label
 import org.apache.linkis.manager.label.entity.engine.{EngineTypeLabel, UserCreatorLabel}
@@ -149,7 +152,7 @@ class TrinoEngineConnExecutor(override val outputPrintLimit: Int, val id: Int)
       code: String
   ): ExecuteResponse = {
     val enableSqlHook = TRINO_SQL_HOOK_ENABLED.getValue
-    val realCode = if (StringUtils.isBlank(code)) {
+    var realCode = if (StringUtils.isBlank(code)) {
       "SELECT 1"
     } else if (enableSqlHook) {
       TrinoSQLHook.preExecuteHook(code.trim)
@@ -159,7 +162,9 @@ class TrinoEngineConnExecutor(override val outputPrintLimit: Int, val id: Int)
 
     TrinoCode.checkCode(realCode)
     logger.info(s"trino client begins to run psql code:\n $realCode")
-
+    val jobId = JobUtils.getJobIdFromMap(engineExecutorContext.getProperties)
+    // Add task id in the first line, and trino will customize it after receiving it.(在第一行加taskid，trino接收后做定制化处理)
+    realCode = s"--linkis_task_id=$jobId" + "\n" + realCode
     val currentUser = getCurrentUser(engineExecutorContext.getLabels)
     val trinoUser = Optional
       .ofNullable(TRINO_DEFAULT_USER.getValue)
@@ -297,8 +302,6 @@ class TrinoEngineConnExecutor(override val outputPrintLimit: Int, val id: Int)
 
   override def getId(): String = Sender.getThisServiceInstance.getInstance + s"_$id"
 
-  override def getConcurrentLimit: Int = ENGINE_CONCURRENT_LIMIT.getValue
-
   private def getClientSession(
       user: String,
       taskParams: util.Map[String, Object],
@@ -374,12 +377,18 @@ class TrinoEngineConnExecutor(override val outputPrintLimit: Int, val id: Int)
       engineExecutorContext: EngineExecutionContext,
       statement: StatementClient
   ): Unit = {
+    var isFirstTime = true
     while (
         statement.isRunning
         && (statement.currentData().getData == null || statement
           .currentStatusInfo()
           .getUpdateType != null)
     ) {
+      val info = statement.currentStatusInfo()
+      if (info != null && isFirstTime) {
+        isFirstTime = false
+        engineExecutorContext.appendStdout(LogUtils.generateInfo(s"Trino query id:[${info.getId}]"))
+      }
       engineExecutorContext.pushProgress(progress(taskId), getProgressInfo(taskId))
       statement.advance()
     }
@@ -400,14 +409,21 @@ class TrinoEngineConnExecutor(override val outputPrintLimit: Int, val id: Int)
       } else {
         results = statement.finalStatusInfo()
       }
+      // v407中create table时columns返回为null
       if (results.getColumns == null) {
-        throw new RuntimeException("trino columns is null.")
+        // throw new RuntimeException("trino columns is null.")
+        logger.info(s"results columns is null for task: $taskId")
+        return
       }
+
       val columns = results.getColumns.asScala
         .map(column => Column(column.getName, column.getType, ""))
         .toArray[Column]
+      // 兼容结果集中colums为空集合的情况，如use db, drop table if exists
+      if (columns.length != 0) {
+        resultSetWriter.addMetaData(new TableMetaData(columns))
+      }
       columnCount = columns.length
-      resultSetWriter.addMetaData(new TableMetaData(columns))
       while (statement.isRunning) {
         val data = statement.currentData().getData
         if (data != null) for (row <- data.asScala) {
@@ -527,6 +543,19 @@ class TrinoEngineConnExecutor(override val outputPrintLimit: Int, val id: Int)
   }
 
   override def close(): Unit = {
+    val taskIds = statementClientCache.keySet().iterator()
+    val lbs = ExecutorListenerBusContext.getExecutorListenerBusContext()
+    while (taskIds.hasNext) {
+      val taskId = taskIds.next()
+      Utils.tryAndWarn(
+        lbs.getEngineConnSyncListenerBus.postToAll(
+          TaskLogUpdateEvent(
+            taskId,
+            LogUtils.generateERROR("EC exits unexpectedly and actively kills the task")
+          )
+        )
+      )
+    }
     killAll()
     super.close()
   }
