@@ -18,6 +18,7 @@
 package org.apache.linkis.configuration.constant
 
 import org.apache.linkis.common.conf.CommonVars
+import org.apache.linkis.common.conf.Configuration.LINKIS_TOKEN
 
 object Constants {
 
@@ -28,7 +29,7 @@ object Constants {
     CommonVars[String]("linkis.configuration.linkisclient.auth.token.key", "Validation-Code")
 
   val AUTH_TOKEN_VALUE: CommonVars[String] =
-    CommonVars[String]("linkis.configuration.linkisclient.auth.token.value", "LINKIS-AUTH")
+    CommonVars[String]("linkis.configuration.linkisclient.auth.token.value", LINKIS_TOKEN.getValue)
 
   val CONNECTION_MAX_SIZE: CommonVars[Int] =
     CommonVars[Int]("linkis.configuration.linkisclient.connection.max.size", 10)
