@@ -102,7 +102,7 @@ public class JobHistoryMapperTest extends BaseDaoTest {
     status.add("Succeed");
     Date eDate = new Date(System.currentTimeMillis());
     Date sDate = DateUtils.addDays(eDate, -1);
-    List<JobHistory> histories = jobHistoryMapper.searchWithIdOrderAsc(sDate, eDate, 1L, status);
+    List<Integer> histories = jobHistoryMapper.searchWithIdOrderAsc(sDate, eDate, 1L, status);
     Assertions.assertTrue(histories.isEmpty());
   }
 
