@@ -17,6 +17,6 @@
 
 DELETE FROM linkis_ps_common_lock;
 
-insert into linkis_ps_common_lock(`id`,`lock_object`,`time_out`,`update_time`,`create_time`) values (1,'hadoop-warehouse',1000000,now(),now());
+insert into linkis_ps_common_lock(`id`,`lock_object`, `locker`, `time_out`,`update_time`,`create_time`) values (1,'hadoop-warehouse', 'test', 1000000,now(),now());
 
 
